<?php
/*
 * Version: 1.1.1
 */



if (!class_exists('oftsCommon')) {

	class oftsCommon {

        public static $plugin_name = 'Options for Twenty Seventeen';
        public static $plugin_prefix = 'ofts';
        public static $plugin_text_domain = 'options-for-twenty-seventeen';
        public static $plugin_premium_class = 'options_for_twenty_seventeen_premium_class';

		public static function plugin_version() {

            return options_for_twenty_seventeen_class::$version;

        }

        public static function plugin_name() {

            return self::$plugin_name;

        }

        public static function plugin_prefix() {

            return self::$plugin_prefix;

        }

        public static function plugin_text_domain() {

            return self::$plugin_text_domain;

        }

        public static function support_url() {

            return 'https://wordpress.org/support/plugin/' . self::$plugin_text_domain;

        }

        public static function control_upgrade_text() {

            $upgrade_text = '<a href="' . self::upgrade_link() . '" title="' . __('Upgrade to ' . self::$plugin_name . ' Premium', self::$plugin_text_domain) . '">' . __('Upgrade to ' . self::$plugin_name . ' Premium', self::$plugin_text_domain) . '</a>';

            if (!class_exists(self::$plugin_premium_class) || !get_option(self::$plugin_prefix . '_purchased')) {

                if (!class_exists(self::$plugin_premium_class)) {

                    $upgrade_text .= __(' or ', self::$plugin_text_domain) . '<a href="' . self::premium_link() . '" title="' . __('Download Free Trial', self::$plugin_text_domain) . '">' . __('try the premium plugin', self::$plugin_text_domain) . '</a>';

                }

            }

            return $upgrade_text;

        }

        public static function control_section_description() {

            $default_description = sprintf(wp_kses(__('If you have any requests for new features, please <a href="%s">let us know in the support forum</a>.', self::$plugin_text_domain), array('a' => array('href' => array()))), esc_url(self::support_url()));
            $upgrade_text = self::control_upgrade_text();

            if (!class_exists(self::$plugin_premium_class) || !get_option(self::$plugin_prefix . '_purchased')) {

                if (!class_exists(self::$plugin_premium_class)) {

                    $section_description = '<strong>' . __('For even more options', self::$plugin_text_domain) . '</strong>' . ' ' . $upgrade_text;

                } else {

                    $section_description = '<strong>' . __('To keep using premium options', self::$plugin_text_domain) . '</strong>' . ' ' . $upgrade_text;

                }

            } else {

                $section_description = $default_description;

            }

            return $section_description;

        }

        public static function control_setting_upgrade_nag() {

            $upgrade_nag = self::control_upgrade_text() . __(' to use this option.', self::$plugin_text_domain);

            return $upgrade_nag;

        }

		public static function get_home_path() {

            if (!function_exists('get_home_path')) {

                require_once(ABSPATH . 'wp-admin/includes/file.php');

            }

            return get_home_path();

		}

        public static function add_hidden_control($wp_customize, $id, $section, $label = '', $description = '', $priority = 11) {

            $wp_customize->add_control($id, array(
                'label'         => $label,
                'description'   => $description,
                'section'       => $section,
                'settings'      => array(),
                'type'          => 'hidden',
				'priority'      => $priority
            ));

        }

		public static function sanitize_boolean($input = false) {

            if ($input) {

                return true;

            }

            return false;

        }

		public static function sanitize_options($input, $setting) {

            $choices = $setting->manager->get_control($setting->id)->choices;

            return (array_key_exists($input, $choices) ? $input : $setting->default);

        }

		public static function generate_css($selector, $style, $mod_name, $prefix = '', $postfix = '', $value = '') {

            $generated_css = '';
            $mod = get_theme_mod($mod_name);

            if ($mod && $value === '') {

                $generated_css = sprintf('%s { %s: %s; }', $selector, $style, $prefix.$mod.$postfix);
                echo $generated_css;

            } elseif ($mod) {

                $generated_css = sprintf('%s { %s:%s; }', $selector, $style, $prefix.$value.$postfix);
                echo $generated_css;

            }

        }

        public static function upgrade_link() {

            return add_query_arg('url', (isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'], 'https://webd.uk/product/' . self::$plugin_text_domain . '-upgrade/');

        }

        public static function premium_link() {

            return 'https://webd.uk/downloads/';

        }

        public static function plugin_action_links($settings_link, $premium = false, $trial = true) {

            $settings_links = array();

			$settings_links[] = '<a href="' . $settings_link . '" title="' . __('Settings', self::$plugin_text_domain) . '">' . __('Settings', self::$plugin_text_domain) . '</a>';

            if (!get_option(self::$plugin_prefix . '_purchased')) {

                if ($premium) {

                    $settings_links[] = '<a href="' . self::upgrade_link() . '" title="' . __('Buy ' . self::$plugin_name, self::$plugin_text_domain) . ' Premium" style="color: orange; font-weight: bold;">' . __('Buy Now', self::$plugin_text_domain) . '</a>';

                } else {

                    $settings_links[] = '<a href="' . self::upgrade_link() . '" title="' . __('Upgrade to ' . self::$plugin_name, self::$plugin_text_domain) . ' Premium" style="color: orange; font-weight: bold;">' . __('Upgrade', self::$plugin_text_domain) . '</a>';

                }

                if ($premium) {

                    $settings_links[] = '<a href="' . wp_nonce_url('?activate-' . self::$plugin_prefix . '=true', self::$plugin_prefix . '_activate') . '" id="' . self::$plugin_prefix . '_activate_upgrade" title="' . __('Activate Premium', self::$plugin_text_domain) . '" onclick="jQuery(this).append(&#39; <img src=&#34;/wp-admin/images/loading.gif&#34; style=&#34;float: none; width: auto; height: auto;&#34; />&#39;); setTimeout(function(){document.getElementById(\'' . self::$plugin_prefix . '_activate_upgrade\').removeAttribute(\'href\');},1); return true;">' . __('Activate Purchase', self::$plugin_text_domain) . '</a>';

                } elseif ($trial && !is_plugin_active(self::$plugin_text_domain . '-premium/' . self::$plugin_text_domain . '-premium.php')) {

                    $settings_links[] = '<a href="' . self::premium_link() . '" title="' . __('Try ' . self::$plugin_name . ' Premium', self::$plugin_text_domain) . '">' . __('Download Trial', self::$plugin_text_domain) . '</a>';

                }

            } elseif ($premium) {

                $settings_links[] = '<strong style="color: green; display: inline;">' . __('Purchase Confirmed', self::$plugin_text_domain) . '</strong>';

            }

			return $settings_links;

		}

        public static function ajax_notice_handler() {

            check_ajax_referer(self::$plugin_prefix . '-ajax-nonce');
            update_user_meta(get_current_user_id(), self::$plugin_prefix . '-notice-dismissed', self::plugin_version());

        }

        public static function admin_notices() {

            if (get_option(self::$plugin_prefix . '_purchased') && !class_exists(self::$plugin_premium_class) && get_user_meta(get_current_user_id(), self::$plugin_prefix . '-notice-dismissed', true) != self::plugin_version()) {

?>

<div class="notice notice-error is-dismissible <?= self::$plugin_prefix; ?>-notice">

<p><strong><?php _e(self::$plugin_name, self::$plugin_text_domain); ?></strong><br />
<?php _e('In order to use the premium options of this plugin, you need to install the premium version of the plugin ...', self::$plugin_text_domain); ?></p>

<p><a href="<?= self::premium_link(); ?>" title="<?= __('Download ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?>" class="button-primary"><?= __('Download ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?></a></p>

</div>

<script type="text/javascript">
    jQuery(document).on('click', '.<?= self::$plugin_prefix; ?>-notice .notice-dismiss', function() {
	    jQuery.ajax({
    	    url: ajaxurl,
    	    data: {
        		action: 'dismiss_<?= self::$plugin_prefix; ?>_notice_handler',
        		_ajax_nonce: '<?= wp_create_nonce(self::$plugin_prefix . '-ajax-nonce'); ?>'
    	    }
    	});
    });
</script>

<?php

            } elseif (!class_exists(self::$plugin_premium_class) && time() > (strtotime('+1 hour', filectime(__DIR__))) && get_user_meta(get_current_user_id(), self::$plugin_prefix . '-notice-dismissed', true) != self::plugin_version()) {

?>

<div class="notice notice-info is-dismissible <?= self::$plugin_prefix; ?>-notice">

<p><strong><?php _e('Thank you for using ' . self::$plugin_name . ' plugin', self::$plugin_text_domain); ?></strong><br />
<?php _e('Would you like to try even more features? Download your 7 day free trial now!', self::$plugin_text_domain); ?></p>

<p><a href="<?= self::premium_link(); ?>" title="<?= __('Try ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?>" class="button-primary"><?= __('Try ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?></a>
<a href="<?= self::upgrade_link(); ?>" title="<?= __('Upgrade to ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?>" class="button-primary"><?= __('Upgrade to ' . self::$plugin_name . ' Premium', self::$plugin_text_domain); ?></a></p>

</div>

<script type="text/javascript">
    jQuery(document).on('click', '.<?= self::$plugin_prefix; ?>-notice .notice-dismiss', function() {
	    jQuery.ajax({
    	    url: ajaxurl,
    	    data: {
        		action: 'dismiss_<?= self::$plugin_prefix; ?>_notice_handler',
        		_ajax_nonce: '<?= wp_create_nonce(self::$plugin_prefix . '-ajax-nonce'); ?>'
    	    }
    	});
    });
</script>

<?php

            }

        }

	}

}

?>
